==> recital-0.2.0.tar.gz: recital-0.2.0/recital/api/extract_task_results/get_export_task.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    task_id: int,
    nb_chunks: Union[Unset, int] = 1,
) -> Dict[str, Any]:
    url = "{}/api/v1/extract/results/export/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "task_id": task_id,
        "nb_chunks": nb_chunks,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[None, None, None, None, None, HTTPValidationError]]:
    if response.status_code == 202:
        response_202 = None

        return response_202
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 409:
        response_409 = None

        return response_409
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[None, None, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    task_id: int,
    nb_chunks: Union[Unset, int] = 1,
) -> Response[Union[None, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        task_id=task_id,
        nb_chunks=nb_chunks,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    task_id: int,
    nb_chunks: Union[Unset, int] = 1,
) -> Optional[Union[None, None, None, None, None, HTTPValidationError]]:
    """Runs the export of extract results.task_id

    The export is generated asynchronously, the user receives a notification when the
    export is ready to be downloaded.

    Only complete tasks can be exported.

    Only orgadmins can export results."""

    return sync_detailed(
        client=client,
        task_id=task_id,
        nb_chunks=nb_chunks,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    task_id: int,
    nb_chunks: Union[Unset, int] = 1,
) -> Response[Union[None, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        task_id=task_id,
        nb_chunks=nb_chunks,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    task_id: int,
    nb_chunks: Union[Unset, int] = 1,
) -> Optional[Union[None, None, None, None, None, HTTPValidationError]]:
    """Runs the export of extract results.task_id

    The export is generated asynchronously, the user receives a notification when the
    export is ready to be downloaded.

    Only complete tasks can be exported.

    Only orgadmins can export results."""

    return (
        await asyncio_detailed(
            client=client,
            task_id=task_id,
            nb_chunks=nb_chunks,
        )
    ).parsed

==> recital-0.6.0.tar.gz: recital-0.6.0/recital/api/extract_task_results/get_export_task.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    task_id: int,
    nb_chunks: Union[Unset, int] = 1,
) -> Dict[str, Any]:
    url = "{}/api/v1/extract/results/export/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "task_id": task_id,
        "nb_chunks": nb_chunks,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[HTTPValidationError, None]]:
    if response.status_code == 202:
        response_202 = None

        return response_202
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 409:
        response_409 = None

        return response_409
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[HTTPValidationError, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    task_id: int,
    nb_chunks: Union[Unset, int] = 1,
) -> Response[Union[HTTPValidationError, None]]:
    kwargs = _get_kwargs(
        client=client,
        task_id=task_id,
        nb_chunks=nb_chunks,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    task_id: int,
    nb_chunks: Union[Unset, int] = 1,
) -> Optional[Union[HTTPValidationError, None]]:
    """Runs the export of extract results.task_id

    The export is generated asynchronously, the user receives a notification when the
    export is ready to be downloaded.

    Only complete tasks can be exported.

    Only orgadmins can export results."""

    return sync_detailed(
        client=client,
        task_id=task_id,
        nb_chunks=nb_chunks,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    task_id: int,
    nb_chunks: Union[Unset, int] = 1,
) -> Response[Union[HTTPValidationError, None]]:
    kwargs = _get_kwargs(
        client=client,
        task_id=task_id,
        nb_chunks=nb_chunks,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    task_id: int,
    nb_chunks: Union[Unset, int] = 1,
) -> Optional[Union[HTTPValidationError, None]]:
    """Runs the export of extract results.task_id

    The export is generated asynchronously, the user receives a notification when the
    export is ready to be downloaded.

    Only complete tasks can be exported.

    Only orgadmins can export results."""

    return (
        await asyncio_detailed(
            client=client,
            task_id=task_id,
            nb_chunks=nb_chunks,
        )
    ).parsed
